summaryrefslogtreecommitdiff
path: root/examples/APG/Config/HA_Status.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/APG/Config/HA_Status.cpp')
-rw-r--r--examples/APG/Config/HA_Status.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/APG/Config/HA_Status.cpp b/examples/APG/Config/HA_Status.cpp
index 1bad687be80..6fac607d8e6 100644
--- a/examples/APG/Config/HA_Status.cpp
+++ b/examples/APG/Config/HA_Status.cpp
@@ -27,14 +27,14 @@ int
HA_Status::init (int argc, ACE_TCHAR *argv[])
{
// Do ACE_Get_Opt and get conf file name, read out the sections
// and print the names.
// Listing 1 code/ch04
static const ACE_TCHAR options[] = ACE_TEXT (":f:");
- ACE_Get_Opt cmd_opts (argc, argv, options);
+ ACE_Get_Arg_Opt<ACE_TCHAR> cmd_opts (argc, argv, options);
if (cmd_opts.long_option
- (ACE_TEXT ("config"), 'f', ACE_Get_Opt::ARG_REQUIRED) == -1)
+ (ACE_TEXT ("config"), 'f', ACE_Get_Arg_Opt<ACE_TCHAR>::ARG_REQUIRED) == -1)
return -1;
int option;
ACE_TCHAR config_file[MAXPATHLEN];
@@ -27,14 +27,14 @@ int
HA_Status::init (int argc, ACE_TCHAR *argv[])
{
- // Do ACE_Get_Opt and get conf file name, read out the sections
+ // Do ACE_Get_Arg_Opt and get conf file name, read out the sections
// and print the names.
// Listing 1 code/ch04